@@ -1,6 +1,6 @@
 from approvaltests.core.reporter import Reporter
 from approvaltests.reporters.clipboard_reporter import get_command_text
-from approvaltests.utilities.clipboard_utilities import copy_to_clipboard
+from approval_utilities.utilities.clipboard_utilities import copy_to_clipboard
 
 
 class ReporterByCopyMoveCommandForEverythingToClipboard(Reporter):
